summaryrefslogtreecommitdiff
path: root/embeddedobj/source/msole/olepersist.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'embeddedobj/source/msole/olepersist.cxx')
-rw-r--r--embeddedobj/source/msole/olepersist.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/embeddedobj/source/msole/olepersist.cxx b/embeddedobj/source/msole/olepersist.cxx
index f1f36dafd586..38790e42ff76 100644
--- a/embeddedobj/source/msole/olepersist.cxx
+++ b/embeddedobj/source/msole/olepersist.cxx
@@ -1417,13 +1417,13 @@ void SAL_CALL OleEmbeddedObject::setPersistentEntry(
&& ( m_nObjectState == -1 || nEntryConnectionMode != embed::EntryInitModes::NO_INIT ) )
{
// if the object is not loaded
// it can not get persistant representation without initialization
// if the object is loaded
// it can switch persistant representation only without initialization
throw embed::WrongStateException(
- ::rtl::OUString::createFromAscii( "Can't change persistant representation of activated object!\n" ),
+ ::rtl::OUString::createFromAscii( "Can't change persistent representation of activated object!\n" ),
uno::Reference< uno::XInterface >( static_cast< ::cppu::OWeakObject* >(this) ) );
}
@@ -1417,13 +1417,13 @@ void SAL_CALL OleEmbeddedObject::setPersistentEntry(
{
// if the object is not loaded
- // it can not get persistant representation without initialization
+ // it can not get persistent representation without initialization
// if the object is loaded
@@ -1417,13 +1417,13 @@ void SAL_CALL OleEmbeddedObject::setPersistentEntry(
// if the object is loaded
- // it can switch persistant representation only without initialization
+ // it can switch persistent representation only without initialization
throw embed::WrongStateException(